==> unicon-19.4.2b0-cp35-cp35m-macosx_10_10_x86_64.whl: unicon/plugins/iosxr/spitfire/statements.py <==
from unicon.plugins.generic.statements import GenericStatements
from unicon.plugins.iosxr.spitfire.patterns import SpitfirePatterns
from unicon.eal.dialogs import Statement, Dialog
from unicon.eal.helpers import sendline
import time

patterns = SpitfirePatterns()

def password_handler(spawn, context, session):
    """ handles password prompt
    """
    spawn_command = spawn.spawn_command
    spawn_command_list = spawn_command.split()
    protocol = spawn_command_list[0]

    if session.get('enable_login') == 1:
        spawn.sendline(context['xr_password'])
    elif session.get('bmc_login') == 1:
        spawn.sendline(context['bmc_password'])
    else:
        spawn.sendline(context['xr_password'])
        # if this password fails, try with tacacs password
        session['tacacs_login'] = 1


def xr_login_handler(spawn, context, session):
    """ handles xr login prompt
    """
    spawn.sendline(context['xr_username'])
    session['enable_login'] = 1

def bmc_login_handler(spawn, context, session):
    """ handles bmc login prompt
    """
    session['bmc_login']=1
    spawn.sendline(context['bmc_username'])

class SpitfireStatements(GenericStatements):
    def __init__(self):
        super().__init__()

        self.login_stmt = Statement(pattern=patterns.username_prompt,
                                       action=xr_login_handler,
                                       args=None,
                                       loop_continue=True,
                                       continue_timer=False)



        self.bmc_login_stmt = Statement(pattern=patterns.bmc_login_prompt,
                                       action=bmc_login_handler,
                                       args=None,
                                       loop_continue=True,
                                       continue_timer=False)

        self.password_stmt = Statement(pattern=patterns.password_prompt,
                                       action=password_handler,
                                       args=None,
                                       loop_continue=True,
                                       continue_timer=False)

spitfire_statements = SpitfireStatements()

#############################################################
# Initial connection Statement
#############################################################

pre_connection_statement_list = [spitfire_statements.escape_char_stmt,
                                 spitfire_statements.press_return_stmt,
                                 spitfire_statements.continue_connect_stmt,
                                 spitfire_statements.connection_refused_stmt,
                                 spitfire_statements.disconnect_error_stmt]

#############################################################
# Authentication Statement
#############################################################

authentication_statement_list = [spitfire_statements.bad_password_stmt,
                                 spitfire_statements.login_incorrect,
                                 spitfire_statements.bmc_login_stmt,
                                 spitfire_statements.login_stmt,
                                 spitfire_statements.useraccess_stmt,
                                 spitfire_statements.password_stmt
                                 ]

connection_statement_list = authentication_statement_list + pre_connection_statement_list

==> unicon-19.6-cp35-cp35m-macosx_10_10_x86_64.whl: unicon/plugins/iosxr/spitfire/statements.py <==
from unicon.plugins.generic.statements import GenericStatements
from unicon.plugins.iosxr.spitfire.patterns import SpitfirePatterns
from unicon.eal.dialogs import Statement, Dialog
from unicon.eal.helpers import sendline
import time

patterns = SpitfirePatterns()

def password_handler(spawn, context, session):
    """ handles password prompt
    """
    spawn_command = spawn.spawn_command
    spawn_command_list = spawn_command.split()
    protocol = spawn_command_list[0]

    if session.get('enable_login') == 1:
        spawn.sendline(context['enable_password'])
    elif session.get('bmc_login') == 1:
        spawn.sendline(context['bmc_password'])
    else:
        spawn.sendline(context['xr_password'])
        # if this password fails, try with tacacs password
        session['tacacs_login'] = 1


def xr_login_handler(spawn, context, session):
    """ handles xr login prompt
    """
    spawn.sendline(context['username'])
    session['enable_login'] = 1

def bmc_login_handler(spawn, context, session):
    """ handles bmc login prompt
    """
    session['bmc_login']=1
    spawn.sendline(context['bmc_username'])

class SpitfireStatements(GenericStatements):
    def __init__(self):
        super().__init__()

        self.login_stmt = Statement(pattern=patterns.username_prompt,
                                       action=xr_login_handler,
                                       args=None,
                                       loop_continue=True,
                                       continue_timer=False)



        self.bmc_login_stmt = Statement(pattern=patterns.bmc_login_prompt,
                                       action=bmc_login_handler,
                                       args=None,
                                       loop_continue=True,
                                       continue_timer=False)

        self.password_stmt = Statement(pattern=patterns.password_prompt,
                                       action=password_handler,
                                       args=None,
                                       loop_continue=True,
                                       continue_timer=False)

spitfire_statements = SpitfireStatements()

#############################################################
# Initial connection Statement
#############################################################

pre_connection_statement_list = [spitfire_statements.escape_char_stmt,
                                 spitfire_statements.press_return_stmt,
                                 spitfire_statements.continue_connect_stmt,
                                 spitfire_statements.connection_refused_stmt,
                                 spitfire_statements.disconnect_error_stmt]

#############################################################
# Authentication Statement
#############################################################

authentication_statement_list = [spitfire_statements.bad_password_stmt,
                                 spitfire_statements.login_incorrect,
                                 spitfire_statements.bmc_login_stmt,
                                 spitfire_statements.login_stmt,
                                 spitfire_statements.useraccess_stmt,
                                 spitfire_statements.password_stmt
                                 ]

connection_statement_list = authentication_statement_list + pre_connection_statement_list
